==> haskell-bsb-http-chunked-0.0.0.4-26-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.4
id: bsb-http-chunked-0.0.0.4-5YMOT1wgheuMh9QljLeJZ
key: bsb-http-chunked-0.0.0.4-5YMOT1wgheuMh9QljLeJZ
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
           (c) 2018 Simon Jakobi
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: 02579ba1be7ac60a3036d3f151ed514e
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
import-dirs: /usr/lib/ghc-8.6.5/site-local/bsb-http-chunked-0.0.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bsb-http-chunked-0.0.0.4
hs-libraries: HSbsb-http-chunked-0.0.0.4-5YMOT1wgheuMh9QljLeJZ
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"

==> haskell-bsb-http-chunked-0.0.0.4-27-x86_64.pkg.tar.xz: usr/share/haskell/register/haskell-bsb-http-chunked.sh <==
#!/bin/sh
export PATH='/usr/local/sbin:/usr/local/bin:/usr/bin:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl:/usr/bin/site_perl:/usr/bin/vendor_perl:/usr/bin/core_perl'
echo 'name: bsb-http-chunked
version: 0.0.0.4
id: bsb-http-chunked-0.0.0.4-5BqxJpsQbLzEWyrRm2uZJ5
key: bsb-http-chunked-0.0.0.4-5BqxJpsQbLzEWyrRm2uZJ5
license: BSD-3-Clause
copyright: (c) 2010-2014 Simon Meier
           (c) 2010 Jasper Van der Jeugt
           (c) 2013-2015 Leon P Smith
           (c) 2018 Simon Jakobi
maintainer: Simon Jakobi <simon.jakobi@gmail.com>
author: Jasper Van der Jeugt, Simon Meier, Leon P Smith, Simon Jakobi
stability: Provisional
homepage: http://github.com/sjakobi/bsb-http-chunked
synopsis: Chunked HTTP transfer encoding for bytestring builders
description:
    This library contains functions for encoding [bytestring
    builders](http://hackage.haskell.org/package/bytestring/docs/Data-ByteString-Builder.html#t:Builder)
    for [chunked HTTP\/1.1 transfer](https://en.wikipedia.org/wiki/Chunked_transfer_encoding).
    .
    This functionality was extracted from
    the [blaze-builder](http://hackage.haskell.org/package/blaze-builder)
    package.
category: Data, Network
abi: f55147e70a7cb3f7099e3ac2933312a0
exposed: True
exposed-modules:
    Data.ByteString.Builder.HTTP.Chunked
import-dirs: /usr/lib/ghc-8.6.5/site-local/bsb-http-chunked-0.0.0.4
library-dirs: /usr/lib/ghc-8.6.5/site-local/bsb-http-chunked-0.0.0.4
dynamic-library-dirs: /usr/lib
data-dir: /usr/share/x86_64-linux-ghc-8.6.5/bsb-http-chunked-0.0.0.4
hs-libraries: HSbsb-http-chunked-0.0.0.4-5BqxJpsQbLzEWyrRm2uZJ5
depends:
    base-4.12.0.0 bytestring-0.10.8.2
haddock-interfaces: /usr/share/doc/haskell-bsb-http-chunked/html/bsb-http-chunked.haddock
haddock-html: /usr/share/doc/haskell-bsb-http-chunked/html
' | '/usr/bin/ghc-pkg' 'update' '--force' '-' '--global' '--no-user-package-db' "$@"
